/*
 * GUMSAuthZServiceImpl.java
 *
 * Created on January 5, 2005, 6:04 PM
 */

package gov.bnl.gums.service;

import gov.bnl.gums.admin.GUMSAPI;
import gov.bnl.gums.admin.GUMSAPIImpl;
import java.util.StringTokenizer;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.opensciencegrid.authz.common.GridId;
import org.opensciencegrid.authz.common.LocalId;
import org.opensciencegrid.authz.service.GRIDIdentityMappingService;

/** Implements a GRID Identity Mapping Service by using GUMS logic.
 *
 * @author Gabriele Carcassi
 */
public class GUMSAuthZServiceImpl implements GRIDIdentityMappingService {
    private Log log = LogFactory.getLog(GUMSAuthZServiceImpl.class);
    private static GUMSAPI gums = new GUMSAPIImpl();
    
    public LocalId mapCredentials(GridId gridID) {
        log.debug("Mapping credentials on '" + gridID.getHostDN() + "' for '" + gridID.getUserDN() + "' coming as '" + gridID.getUserFQAN() + "' authenticated by '" + gridID.getUserFQANIssuer() + "'");
        if (gridID.getHostDN() == null) throw new RuntimeException("The request had a null host");
        StringTokenizer tokenizer = new StringTokenizer(gridID.getHostDN(), "/");
        String hostname = null;
        while (tokenizer.hasMoreTokens()) {
            String token = tokenizer.nextToken();
            if (token.startsWith("CN=")) {
                hostname = token.substring(3);
            }
        }
        if (hostname == null) throw new RuntimeException("Couldn't retrieve the hostname from the certificate DN: " + gridID.getHostDN());
        String username = gums.mapUser(hostname, gridID.getUserDN(), gridID.getUserFQAN());
        log.debug("Denied access");
        if (username == null)
            return null;
        LocalId id = new LocalId();
        id.setUserName(username);
        log.debug("Credentials mapped on '" + hostname + "' to '" + id.getUserName() + "' part of '" + id.getGroupName() + "'");
        return id;
    }
    
}
